Одеський Національний технологічний університет

## Розклад навчальних занять

Сьогодні: 5 вересня 2022р. ()
Розклад перескладань доступний за посиланням "Розклад перескладань"

- 0

##### Розклад на поточний тиждень

День | Пара | А-30
--- | --- | ---
а | б
# П о н е д і л о к | ## 1 |  |
## 2 | АЕП (Онлайн лек.) Осадчук П. І. Ідентифікатор/Код ﻿Petr Osadchuk приглашает вас на запланированную конференцию: Zoom. Тема: Автоматизований електропривод Идентификатор конференции: 840 1144 5726 Код доступа: ZCp5dT | АЕП (Онлайн лек.) Осадчук П. І. Ідентифікатор/Код ﻿Petr Osadchuk приглашает вас на запланированную конференцию: Zoom. Тема: Автоматизований електропривод Идентификатор конференции: 840 1144 5726 Код доступа: ZCp5dT
## 3 | ЛКТРС (Онлайн лек.) Світий І. М. Ідентифікатор/Код ﻿switiy@yahoo.com приглашает вас на запланированную конференцию: Zoom. Тема: Лекція з ЛКТРС Время: 5 сент. 2022 11:30 AM Киев Подключиться к конференции Zoom https://us04web.zoom.us/j/76523140585?pwd=Q8oh6Lui2gI8f466Glabetu1wDtyIG.1 Идентификатор конференции: 765 2314 0585 Код доступа: 2022 | ЛКТРС (Онлайн лек.) Світий І. М. Ідентифікатор/Код ﻿switiy@yahoo.com приглашает вас на запланированную конференцию: Zoom. Тема: Лекція з ЛКТРС Время: 5 сент. 2022 11:30 AM Киев Подключиться к конференции Zoom https://us04web.zoom.us/j/76523140585?pwd=Q8oh6Lui2gI8f466Glabetu1wDtyIG.1 Идентификатор конференции: 765 2314 0585 Код доступа: 2022
## 4 |  |
## 5 |  |
# В і в т о р о к | ## 1 |  |
## 2 | ЛКТРС (Онлайн лек.) Світий І. М. Ідентифікатор/Код | ЛКТРС (Онлайн лек.) Світий І. М. Ідентифікатор/Код
## 3 | ЛКТРС (Онлайн лек.) Світий І. М. Ідентифікатор/Код | ЛКТРС (Онлайн лек.) Світий І. М. Ідентифікатор/Код
## 4 |  |
## 5 |  |
# С е р е д а | ## 1 |  |
## 2 | БЖДтаООП (Онлайн практ.) Неменуща С. М. Ідентифікатор/Код ZOOM: 266 077 8838 Код доступа: 3evcc6 телеграм/вайбер 0956471608 пошта s_nem_od@ukr.net | БЖДтаООП (Онлайн практ.) Неменуща С. М. Ідентифікатор/Код ZOOM: 266 077 8838 Код доступа: 3evcc6 телеграм/вайбер 0956471608 пошта s_nem_od@ukr.net
## 3 | БЖДтаООП (Онлайн практ.) Неменуща С. М. Ідентифікатор/Код ZOOM: 266 077 8838 Код доступа: 3evcc6 телеграм/вайбер 0956471608 пошта s_nem_od@ukr.net | БЖДтаООП (Онлайн практ.) Неменуща С. М. Ідентифікатор/Код ZOOM: 266 077 8838 Код доступа: 3evcc6 телеграм/вайбер 0956471608 пошта s_nem_od@ukr.net
## 4 |  |
## 5 |  |
# Ч е т в е р | ## 1 |  |
## 2 | ЕтаМПТ (Онлайн лек.) Мазур О. В. Ідентифікатор/Код 6595926813 Код 7ZD2gN | ЕтаМПТ (Онлайн лек.) Мазур О. В. Ідентифікатор/Код 6595926813 Код 7ZD2gN
## 3 | ЕтаМПТ (Онлайн лек.) Мазур О. В. Ідентифікатор/Код 6595926813 Код 7ZD2gN | ЕтаМПТ (Онлайн лек.) Мазур О. В. Ідентифікатор/Код 6595926813 Код 7ZD2gN
## 4 |  |
## 5 |  |
# П ` я т н и ц я | ## 1 |  |
## 2 |  |
## 3 | ТАК (Онлайн лек.) Хобін В. А. Ідентифікатор/Код Подключиться к конференции Zoom https://us04web.zoom.us/j/3644954894?pwd=UldpSi83SEptY2E1aUprR0hoNXRpZz09 Идентификатор конференции: 364 495 4894 Код доступа: 176062 | ТАК (Онлайн лек.) Хобін В. А. Ідентифікатор/Код Подключиться к конференции Zoom https://us04web.zoom.us/j/3644954894?pwd=UldpSi83SEptY2E1aUprR0hoNXRpZz09 Идентификатор конференции: 364 495 4894 Код доступа: 176062
## 4 |  |
## 5 |  |
# С у б о т а | ## 1 |  |
## 2 |  |
## 3 |  |
## 4 |  |
## 5 |  |

##### Розклад екзаменів та перескладань

##### Оголошення

##### Файли